Skip to contents

Computes area-level coverage quantities from active users and population. The primary bias measure is defined as: $$coverage\_bias_i = 1 - \frac{U_i}{P_i}$$ where \(U_i\) is user count and \(P_i\) is population in area \(i\). The function also returns: $$coverage\_score_i = \frac{U_i}{P_i}$$

Usage

measure_bias(coverage_df)

Arguments

coverage_df

A data frame with one row per area, containing the following columns:

  • population — Benchmark population count for the area.

  • user_count — Number of active users from mobile phone data.

Value

The input coverage_df with an added column:

  • coverage_bias — Defined as 1 - user_count / population.

  • coverage_score — Defined as user_count / population (1 indicates full coverage, 0 indicates no coverage).

  • bias — Backward-compatible alias of coverage_bias.

Details

This function does not rescale or cap values. If coverage_score > 1, a warning is issued, as this indicates user counts exceeding benchmark population for that area (possible if benchmarks are not accurate, users are overcounted or definitions differ).

Examples

data(simulated_active.users)
data(simulated_pop)
coverage_df <- merge(
  simulated_pop,
  simulated_active.users[c("origin", "user_count")],
  by = "origin"
)
measure_bias(coverage_df)
#>                                  origin population user_count coverage_score
#> 1                                  Adur       4975        558     0.11216080
#> 2                             Allerdale       6750       1005     0.14888889
#> 3                          Amber Valley       9334        808     0.08656525
#> 4                                  Arun      13750       1416     0.10298182
#> 5                              Ashfield       9323       1280     0.13729486
#> 6                               Ashford      12042       1287     0.10687593
#> 7                               Babergh       7491        449     0.05993859
#> 8                  Barking and Dagenham      20930       1279     0.06110846
#> 9                                Barnet      45399       2723     0.05997929
#> 10                             Barnsley      17559       1349     0.07682670
#> 11                    Barrow-in-Furness       5241        314     0.05991223
#> 12                             Basildon      15283       1065     0.06968527
#> 13                Basingstoke and Deane      17786       1729     0.09721129
#> 14                            Bassetlaw       9049       1381     0.15261355
#> 15         Bath and North East Somerset      26446       2273     0.08594873
#> 16                              Bedford      16610        996     0.05996388
#> 17                               Bexley      21096       2568     0.12172924
#> 18                           Birmingham     114070      12416     0.10884545
#> 19                                Blaby       7568        763     0.10081924
#> 20                Blackburn with Darwen      11964       1752     0.14643932
#> 21                            Blackpool      12727       2425     0.19053980
#> 22                        Blaenau Gwent       4458        499     0.11193360
#> 23                             Bolsover       5690        540     0.09490334
#> 24                               Bolton      22462       1710     0.07612857
#> 25                               Boston       6641        769     0.11579581
#> 26  Bournemouth, Christchurch and Poole      47402       5880     0.12404540
#> 27                     Bracknell Forest      12022        721     0.05997338
#> 28                             Bradford      42706       3903     0.09139231
#> 29                            Braintree      12716       1108     0.08713432
#> 30                            Breckland      11740       1173     0.09991482
#> 31                                Brent      48093       7129     0.14823363
#> 32                            Brentwood       7397       1053     0.14235501
#> 33                             Bridgend      10616       1402     0.13206481
#> 34                    Brighton and Hove      45926       5641     0.12282803
#> 35                            Broadland       9740       1382     0.14188912
#> 36                              Bromley      31573       3310     0.10483641
#> 37                           Bromsgrove       7809       1138     0.14572929
#> 38                           Broxbourne       8522        917     0.10760385
#> 39                             Broxtowe      10214       1050     0.10280008
#> 40                      Buckinghamshire      51042       4034     0.07903295
#> 41                              Burnley       7637        942     0.12334686
#> 42                                 Bury      14361       1387     0.09658102
#> 43                           Caerphilly      11312       1608     0.14214993
#> 44                           Calderdale      16803       2022     0.12033565
#> 45                            Cambridge      25470       2960     0.11621516
#> 46                               Camden      37598      10954     0.29134528
#> 47                        Cannock Chase       7032        917     0.13040387
#> 48                           Canterbury      21171       3451     0.16300600
#> 49                              Cardiff      49344       9166     0.18575713
#> 50                             Carlisle       9213       1147     0.12449799
#> 51                      Carmarthenshire      13248        873     0.06589674
#> 52                         Castle Point       6191        371     0.05992570
#> 53                 Central Bedfordshire      24493       2428     0.09913036
#> 54                           Ceredigion       8534        512     0.05999531
#> 55                            Charnwood      20828       1249     0.05996735
#> 56                           Chelmsford      16881       1357     0.08038623
#> 57                           Cheltenham      15015       1521     0.10129870
#> 58                             Cherwell      15595        935     0.05995511
#> 59                        Cheshire East      34359       2238     0.06513577
#> 60            Cheshire West and Chester      31247       7743     0.24779979
#> 61                         Chesterfield       7959       1584     0.19901998
#> 62                           Chichester      12427        828     0.06662911
#> 63                              Chorley       8929        573     0.06417292
#> 64                       City of London       1578       1386     0.87832700
#> 65                           Colchester      22383       1381     0.06169861
#> 66                                Conwy       8565       1182     0.13800350
#> 67                             Copeland       4790        371     0.07745303
#> 68                             Cornwall      51748       5430     0.10493159
#> 69                             Cotswold       9175       1412     0.15389646
#> 70                        County Durham      46805       3534     0.07550475
#> 71                             Coventry      42122       3820     0.09068895
#> 72                               Craven       4500        423     0.09400000
#> 73                              Crawley      11704       1267     0.10825359
#> 74                              Croydon      41151       5519     0.13411582
#> 75                              Dacorum      14423       1901     0.13180337
#> 76                           Darlington       9060        962     0.10618102
#> 77                             Dartford       9977        865     0.08669941
#> 78                         Denbighshire       7615        456     0.05988181
#> 79                                Derby      25808       3721     0.14418010
#> 80                     Derbyshire Dales       5529        492     0.08898535
#> 81                            Doncaster      24111       1446     0.05997263
#> 82                               Dorset      32637       3527     0.10806753
#> 83                                Dover       9445        911     0.09645315
#> 84                               Dudley      21898       1817     0.08297561
#> 85                               Ealing      46479       4318     0.09290217
#> 86                  East Cambridgeshire       7375        747     0.10128814
#> 87                           East Devon      12684        761     0.05999685
#> 88                       East Hampshire      10866       1532     0.14099024
#> 89                   East Hertfordshire      14075        844     0.05996448
#> 90                         East Lindsey      11605       1492     0.12856527
#> 91             East Riding of Yorkshire      26940       2385     0.08853007
#> 92                   East Staffordshire      10120        717     0.07084980
#> 93                         East Suffolk      19571       1956     0.09994379
#> 94                           Eastbourne       9924        619     0.06237404
#> 95                            Eastleigh      11113        764     0.06874831
#> 96                                 Eden       3875        550     0.14193548
#> 97                            Elmbridge      14483       1283     0.08858662
#> 98                              Enfield      33176       2094     0.06311792
#> 99                        Epping Forest      11830        852     0.07202029
#> 100                     Epsom and Ewell       7642        759     0.09931955
#> 101                             Erewash       8597       1283     0.14923811
#> 102                              Exeter      21614       2073     0.09591006
#> 103                             Fareham       9548       1129     0.11824466
#> 104                             Fenland       8517        949     0.11142421
#> 105                          Flintshire      11153       1079     0.09674527
#> 106                Folkestone and Hythe       9237        850     0.09202122
#> 107                      Forest of Dean       6690        401     0.05994021
#> 108                               Fylde       6622        741     0.11189973
#> 109                           Gateshead      15916       1724     0.10831867
#> 110                             Gedling       8831       1916     0.21696297
#> 111                          Gloucester      12721       1634     0.12844902
#> 112                             Gosport       7486        639     0.08535934
#> 113                           Gravesham       8559        840     0.09814231
#> 114                      Great Yarmouth       8599        515     0.05989068
#> 115                           Greenwich      34420       3956     0.11493318
#> 116                           Guildford      20293       2219     0.10934805
#> 117                             Gwynedd      11339        923     0.08140048
#> 118                             Hackney      41331       4856     0.11749050
#> 119                              Halton       9047       1452     0.16049519
#> 120                           Hambleton       7511        709     0.09439489
#> 121              Hammersmith and Fulham      36786       5010     0.13619312
#> 122                          Harborough       7972        635     0.07965379
#> 123                            Haringey      40572       2953     0.07278419
#> 124                              Harlow       8244        996     0.12081514
#> 125                           Harrogate      16059       1531     0.09533595
#> 126                              Harrow      28275       2407     0.08512821
#> 127                                Hart       9244       1179     0.12754219
#> 128                          Hartlepool       7853        640     0.08149752
#> 129                            Hastings       8173        608     0.07439129
#> 130                              Havant       9463        567     0.05991757
#> 131                            Havering      22569       2057     0.09114272
#> 132                           Hertsmere      10187        788     0.07735349
#> 133                           High Peak       7185        585     0.08141962
#> 134                          Hillingdon      32942       3547     0.10767409
#> 135               Hinckley and Bosworth       8766        634     0.07232489
#> 136                             Horsham      12837       1315     0.10243826
#> 137                            Hounslow      34943       3812     0.10909195
#> 138                     Huntingdonshire      15999       1030     0.06437902
#> 139                            Hyndburn       6270        500     0.07974482
#> 140                             Ipswich      13381       1709     0.12771841
#> 141                    Isle of Anglesey       4885        383     0.07840328
#> 142                       Isle of Wight      12934       1292     0.09989176
#> 143                     Isles of Scilly        181         19     0.10497238
#> 144                           Islington      40151       6599     0.16435456
#> 145              Kensington and Chelsea      21626       1875     0.08670119
#> 146        King's Lynn and West Norfolk      12571        755     0.06005887
#> 147                Kingston upon Thames      20504       3254     0.15870074
#> 148                            Kirklees      34167       3433     0.10047707
#> 149                            Knowsley       9592       1676     0.17472894
#> 150                             Lambeth      58920       8973     0.15229124
#> 151                           Lancaster      18598       1151     0.06188838
#> 152                               Leeds      99126       8336     0.08409499
#> 153                           Leicester      42226       5528     0.13091460
#> 154                               Lewes       8680        801     0.09228111
#> 155                            Lewisham      40089       5754     0.14353064
#> 156                           Lichfield       8502        981     0.11538462
#> 157                             Lincoln      16769       1881     0.11217127
#> 158                           Liverpool      57511      15572     0.27076559
#> 159                               Luton      21444       1361     0.06346764
#> 160                           Maidstone      15868        952     0.05999496
#> 161                              Maldon       4890        304     0.06216769
#> 162                       Malvern Hills       6403        642     0.10026550
#> 163                          Manchester      81735      15883     0.19432312
#> 164                           Mansfield       8448       1044     0.12357955
#> 165                              Medway      25412       1887     0.07425626
#> 166                              Melton       4294        652     0.15183978
#> 167                              Mendip      10073        931     0.09242530
#> 168                      Merthyr Tydfil       3633        526     0.14478393
#> 169                              Merton      27282       3058     0.11208856
#> 170                           Mid Devon       7151        615     0.08600196
#> 171                         Mid Suffolk       8490        639     0.07526502
#> 172                          Mid Sussex      13602       1002     0.07366564
#> 173                       Middlesbrough      13250       1155     0.08716981
#> 174                       Milton Keynes      29401       3562     0.12115234
#> 175                         Mole Valley       7811        587     0.07515043
#> 176                       Monmouthshire       7126        826     0.11591356
#> 177                   Neath Port Talbot      10305       1226     0.11897137
#> 178                          New Forest      14514       1446     0.09962795
#> 179                 Newark and Sherwood      10565        633     0.05991481
#> 180                 Newcastle upon Tyne      45090       3608     0.08001774
#> 181                Newcastle-under-Lyme      11603       1280     0.11031630
#> 182                              Newham      49347       4241     0.08594241
#> 183                             Newport      11720       2165     0.18472696
#> 184                         North Devon       8884        533     0.05999550
#> 185               North East Derbyshire       6742        436     0.06466924
#> 186             North East Lincolnshire      13364        801     0.05993714
#> 187                 North Hertfordshire      12012       1286     0.10705961
#> 188                      North Kesteven      10476        628     0.05994654
#> 189                  North Lincolnshire      13668        903     0.06606673
#> 190                       North Norfolk       7546        452     0.05989928
#> 191              North Northamptonshire      32419       5485     0.16919091
#> 192                      North Somerset      19309       1883     0.09751929
#> 193                      North Tyneside      15813       2039     0.12894454
#> 194                  North Warwickshire       4863        291     0.05983961
#> 195           North West Leicestershire       8612        910     0.10566651
#> 196                      Northumberland      22889       2655     0.11599458
#> 197                             Norwich      22142       1337     0.06038298
#> 198                          Nottingham      49601       4798     0.09673192
#> 199               Nuneaton and Bedworth      10329        989     0.09574983
#> 200                   Oadby and Wigston       5232        458     0.08753823
#> 201                              Oldham      16218       1931     0.11906524
#> 202                              Oxford      31434       3086     0.09817395
#> 203                       Pembrokeshire       9247        785     0.08489240
#> 204                              Pendle       7188        467     0.06496939
#> 205                        Peterborough      21197       2235     0.10543945
#> 206                            Plymouth      30137       2601     0.08630587
#> 207                          Portsmouth      28542       2162     0.07574802
#> 208                               Powys       9940        669     0.06730382
#> 209                             Preston      15756       1379     0.08752221
#> 210                             Reading      26145       2678     0.10242876
#> 211                           Redbridge      32454       2852     0.08787823
#> 212                Redcar and Cleveland       9863       1035     0.10493765
#> 213                            Redditch       6922        586     0.08465761
#> 214                Reigate and Banstead      14572        874     0.05997804
#> 215                   Rhondda Cynon Taf      17305       1241     0.07171338
#> 216                       Ribble Valley       4904        448     0.09135400
#> 217                Richmond upon Thames      24524       1746     0.07119556
#> 218                       Richmondshire       6108        366     0.05992141
#> 219                            Rochdale      15977       2119     0.13262815
#> 220                            Rochford       6099        513     0.08411215
#> 221                          Rossendale       5394        790     0.14645903
#> 222                              Rother       7386        443     0.05997834
#> 223                           Rotherham      19346       2221     0.11480409
#> 224                               Rugby      10483        985     0.09396165
#> 225                           Runnymede      11739       1101     0.09378993
#> 226                          Rushcliffe      11172       1287     0.11519871
#> 227                            Rushmoor      11164       1351     0.12101397
#> 228                             Rutland       3785        416     0.10990753
#> 229                             Ryedale       4470        342     0.07651007
#> 230                             Salford      31648       4108     0.12980283
#> 231                            Sandwell      24829       1788     0.07201257
#> 232                         Scarborough       9086       1733     0.19073300
#> 233                           Sedgemoor      10492        629     0.05995044
#> 234                              Sefton      19736       1400     0.07093636
#> 235                               Selby       7250        574     0.07917241
#> 236                           Sevenoaks      10019       1281     0.12785707
#> 237                           Sheffield      62170      10434     0.16783014
#> 238                          Shropshire      26816       1608     0.05996420
#> 239                              Slough      15494       1122     0.07241513
#> 240                            Solihull      17499       2052     0.11726384
#> 241           Somerset West and Taunton      13782        862     0.06254535
#> 242                South Cambridgeshire      14534       1595     0.10974267
#> 243                    South Derbyshire       8371       1311     0.15661211
#> 244               South Gloucestershire      27983       1678     0.05996498
#> 245                          South Hams       7670        460     0.05997392
#> 246                       South Holland       7940        751     0.09458438
#> 247                      South Kesteven      12163       1106     0.09093151
#> 248                      South Lakeland       8303       1535     0.18487294
#> 249                       South Norfolk      11360       1007     0.08864437
#> 250                   South Oxfordshire      14473       1211     0.08367305
#> 251                        South Ribble       8084       1062     0.13137061
#> 252                      South Somerset      15213       1367     0.08985736
#> 253                 South Staffordshire       7821       1102     0.14090270
#> 254                      South Tyneside      10128       1045     0.10317930
#> 255                         Southampton      33167       3421     0.10314469
#> 256                     Southend-on-Sea      16568       2139     0.12910430
#> 257                           Southwark      52303       6596     0.12611131
#> 258                          Spelthorne       9529        716     0.07513905
#> 259                           St Albans      15662       1570     0.10024263
#> 260                          St. Helens      12298       1939     0.15766791
#> 261                            Stafford      11701       1459     0.12469020
#> 262             Staffordshire Moorlands       6622       1010     0.15252190
#> 263                           Stevenage       7933        847     0.10676919
#> 264                           Stockport      23156       4475     0.19325445
#> 265                    Stockton-on-Tees      16432       1040     0.06329114
#> 266                      Stoke-on-Trent      22772       1647     0.07232566
#> 267                   Stratford-on-Avon      12192       1246     0.10219816
#> 268                              Stroud       9470       1016     0.10728617
#> 269                          Sunderland      20611       2131     0.10339139
#> 270                        Surrey Heath       8805       1138     0.12924475
#> 271                              Sutton      19375       2241     0.11566452
#> 272                               Swale      12323       1268     0.10289702
#> 273                             Swansea      22942       1880     0.08194578
#> 274                             Swindon      22735       1364     0.05999560
#> 275                            Tameside      16440       1917     0.11660584
#> 276                            Tamworth       6382        631     0.09887183
#> 277                           Tandridge       7279        686     0.09424371
#> 278                         Teignbridge      11396        683     0.05993331
#> 279                  Telford and Wrekin      16531       2032     0.12292057
#> 280                            Tendring      11265       1173     0.10412783
#> 281                         Test Valley      11125        857     0.07703371
#> 282                          Tewkesbury       7864        853     0.10846897
#> 283                              Thanet      12091       1210     0.10007444
#> 284                        Three Rivers       7912        827     0.10452477
#> 285                            Thurrock      15007       1696     0.11301393
#> 286               Tonbridge and Malling      11147        668     0.05992644
#> 287                              Torbay      11849        985     0.08312938
#> 288                             Torfaen       6301        897     0.14235836
#> 289                            Torridge       5798        347     0.05984822
#> 290                       Tower Hamlets      56119       8507     0.15158859
#> 291                            Trafford      20168       4436     0.21995240
#> 292                     Tunbridge Wells      11752        904     0.07692308
#> 293                          Uttlesford       7634        613     0.08029866
#> 294                   Vale of Glamorgan      10442       1541     0.14757709
#> 295                 Vale of White Horse      14475       1204     0.08317789
#> 296                           Wakefield      25648       4298     0.16757642
#> 297                             Walsall      20244       2129     0.10516696
#> 298                      Waltham Forest      33374       2307     0.06912567
#> 299                          Wandsworth      65459       5152     0.07870575
#> 300                          Warrington      17888       2061     0.11521691
#> 301                             Warwick      17917       1075     0.05999888
#> 302                             Watford      11068        664     0.05999277
#> 303                            Waverley      12840        870     0.06775701
#> 304                             Wealden      13370        831     0.06215408
#> 305                     Welwyn Hatfield      14308       1420     0.09924518
#> 306                      West Berkshire      15024       1395     0.09285144
#> 307                          West Devon       4611        276     0.05985686
#> 308                     West Lancashire      10305       1381     0.13401262
#> 309                        West Lindsey       7809        580     0.07427327
#> 310               West Northamptonshire      42503       2551     0.06001929
#> 311                    West Oxfordshire      11443        686     0.05994931
#> 312                        West Suffolk      16515       1932     0.11698456
#> 313                         Westminster      34912       7396     0.21184693
#> 314                               Wigan      23015       1580     0.06865088
#> 315                           Wiltshire      48498       4958     0.10223102
#> 316                          Winchester      15406       1685     0.10937297
#> 317              Windsor and Maidenhead      16002        994     0.06211724
#> 318                              Wirral      23840       2142     0.08984899
#> 319                              Woking      11199       1073     0.09581213
#> 320                           Wokingham      16633       1488     0.08946071
#> 321                       Wolverhampton      21021       2247     0.10689311
#> 322                           Worcester      11311       1214     0.10732915
#> 323                            Worthing      10347       1384     0.13375858
#> 324                             Wrexham      10560       1078     0.10208333
#> 325                            Wychavon      10030        736     0.07337986
#> 326                                Wyre       8772        871     0.09929321
#> 327                         Wyre Forest       7450        447     0.06000000
#> 328                                York      28861       4022     0.13935761
#>     coverage_bias      bias
#> 1       0.8878392 0.8878392
#> 2       0.8511111 0.8511111
#> 3       0.9134348 0.9134348
#> 4       0.8970182 0.8970182
#> 5       0.8627051 0.8627051
#> 6       0.8931241 0.8931241
#> 7       0.9400614 0.9400614
#> 8       0.9388915 0.9388915
#> 9       0.9400207 0.9400207
#> 10      0.9231733 0.9231733
#> 11      0.9400878 0.9400878
#> 12      0.9303147 0.9303147
#> 13      0.9027887 0.9027887
#> 14      0.8473865 0.8473865
#> 15      0.9140513 0.9140513
#> 16      0.9400361 0.9400361
#> 17      0.8782708 0.8782708
#> 18      0.8911546 0.8911546
#> 19      0.8991808 0.8991808
#> 20      0.8535607 0.8535607
#> 21      0.8094602 0.8094602
#> 22      0.8880664 0.8880664
#> 23      0.9050967 0.9050967
#> 24      0.9238714 0.9238714
#> 25      0.8842042 0.8842042
#> 26      0.8759546 0.8759546
#> 27      0.9400266 0.9400266
#> 28      0.9086077 0.9086077
#> 29      0.9128657 0.9128657
#> 30      0.9000852 0.9000852
#> 31      0.8517664 0.8517664
#> 32      0.8576450 0.8576450
#> 33      0.8679352 0.8679352
#> 34      0.8771720 0.8771720
#> 35      0.8581109 0.8581109
#> 36      0.8951636 0.8951636
#> 37      0.8542707 0.8542707
#> 38      0.8923962 0.8923962
#> 39      0.8971999 0.8971999
#> 40      0.9209670 0.9209670
#> 41      0.8766531 0.8766531
#> 42      0.9034190 0.9034190
#> 43      0.8578501 0.8578501
#> 44      0.8796643 0.8796643
#> 45      0.8837848 0.8837848
#> 46      0.7086547 0.7086547
#> 47      0.8695961 0.8695961
#> 48      0.8369940 0.8369940
#> 49      0.8142429 0.8142429
#> 50      0.8755020 0.8755020
#> 51      0.9341033 0.9341033
#> 52      0.9400743 0.9400743
#> 53      0.9008696 0.9008696
#> 54      0.9400047 0.9400047
#> 55      0.9400326 0.9400326
#> 56      0.9196138 0.9196138
#> 57      0.8987013 0.8987013
#> 58      0.9400449 0.9400449
#> 59      0.9348642 0.9348642
#> 60      0.7522002 0.7522002
#> 61      0.8009800 0.8009800
#> 62      0.9333709 0.9333709
#> 63      0.9358271 0.9358271
#> 64      0.1216730 0.1216730
#> 65      0.9383014 0.9383014
#> 66      0.8619965 0.8619965
#> 67      0.9225470 0.9225470
#> 68      0.8950684 0.8950684
#> 69      0.8461035 0.8461035
#> 70      0.9244952 0.9244952
#> 71      0.9093110 0.9093110
#> 72      0.9060000 0.9060000
#> 73      0.8917464 0.8917464
#> 74      0.8658842 0.8658842
#> 75      0.8681966 0.8681966
#> 76      0.8938190 0.8938190
#> 77      0.9133006 0.9133006
#> 78      0.9401182 0.9401182
#> 79      0.8558199 0.8558199
#> 80      0.9110147 0.9110147
#> 81      0.9400274 0.9400274
#> 82      0.8919325 0.8919325
#> 83      0.9035469 0.9035469
#> 84      0.9170244 0.9170244
#> 85      0.9070978 0.9070978
#> 86      0.8987119 0.8987119
#> 87      0.9400032 0.9400032
#> 88      0.8590098 0.8590098
#> 89      0.9400355 0.9400355
#> 90      0.8714347 0.8714347
#> 91      0.9114699 0.9114699
#> 92      0.9291502 0.9291502
#> 93      0.9000562 0.9000562
#> 94      0.9376260 0.9376260
#> 95      0.9312517 0.9312517
#> 96      0.8580645 0.8580645
#> 97      0.9114134 0.9114134
#> 98      0.9368821 0.9368821
#> 99      0.9279797 0.9279797
#> 100     0.9006805 0.9006805
#> 101     0.8507619 0.8507619
#> 102     0.9040899 0.9040899
#> 103     0.8817553 0.8817553
#> 104     0.8885758 0.8885758
#> 105     0.9032547 0.9032547
#> 106     0.9079788 0.9079788
#> 107     0.9400598 0.9400598
#> 108     0.8881003 0.8881003
#> 109     0.8916813 0.8916813
#> 110     0.7830370 0.7830370
#> 111     0.8715510 0.8715510
#> 112     0.9146407 0.9146407
#> 113     0.9018577 0.9018577
#> 114     0.9401093 0.9401093
#> 115     0.8850668 0.8850668
#> 116     0.8906519 0.8906519
#> 117     0.9185995 0.9185995
#> 118     0.8825095 0.8825095
#> 119     0.8395048 0.8395048
#> 120     0.9056051 0.9056051
#> 121     0.8638069 0.8638069
#> 122     0.9203462 0.9203462
#> 123     0.9272158 0.9272158
#> 124     0.8791849 0.8791849
#> 125     0.9046641 0.9046641
#> 126     0.9148718 0.9148718
#> 127     0.8724578 0.8724578
#> 128     0.9185025 0.9185025
#> 129     0.9256087 0.9256087
#> 130     0.9400824 0.9400824
#> 131     0.9088573 0.9088573
#> 132     0.9226465 0.9226465
#> 133     0.9185804 0.9185804
#> 134     0.8923259 0.8923259
#> 135     0.9276751 0.9276751
#> 136     0.8975617 0.8975617
#> 137     0.8909081 0.8909081
#> 138     0.9356210 0.9356210
#> 139     0.9202552 0.9202552
#> 140     0.8722816 0.8722816
#> 141     0.9215967 0.9215967
#> 142     0.9001082 0.9001082
#> 143     0.8950276 0.8950276
#> 144     0.8356454 0.8356454
#> 145     0.9132988 0.9132988
#> 146     0.9399411 0.9399411
#> 147     0.8412993 0.8412993
#> 148     0.8995229 0.8995229
#> 149     0.8252711 0.8252711
#> 150     0.8477088 0.8477088
#> 151     0.9381116 0.9381116
#> 152     0.9159050 0.9159050
#> 153     0.8690854 0.8690854
#> 154     0.9077189 0.9077189
#> 155     0.8564694 0.8564694
#> 156     0.8846154 0.8846154
#> 157     0.8878287 0.8878287
#> 158     0.7292344 0.7292344
#> 159     0.9365324 0.9365324
#> 160     0.9400050 0.9400050
#> 161     0.9378323 0.9378323
#> 162     0.8997345 0.8997345
#> 163     0.8056769 0.8056769
#> 164     0.8764205 0.8764205
#> 165     0.9257437 0.9257437
#> 166     0.8481602 0.8481602
#> 167     0.9075747 0.9075747
#> 168     0.8552161 0.8552161
#> 169     0.8879114 0.8879114
#> 170     0.9139980 0.9139980
#> 171     0.9247350 0.9247350
#> 172     0.9263344 0.9263344
#> 173     0.9128302 0.9128302
#> 174     0.8788477 0.8788477
#> 175     0.9248496 0.9248496
#> 176     0.8840864 0.8840864
#> 177     0.8810286 0.8810286
#> 178     0.9003721 0.9003721
#> 179     0.9400852 0.9400852
#> 180     0.9199823 0.9199823
#> 181     0.8896837 0.8896837
#> 182     0.9140576 0.9140576
#> 183     0.8152730 0.8152730
#> 184     0.9400045 0.9400045
#> 185     0.9353308 0.9353308
#> 186     0.9400629 0.9400629
#> 187     0.8929404 0.8929404
#> 188     0.9400535 0.9400535
#> 189     0.9339333 0.9339333
#> 190     0.9401007 0.9401007
#> 191     0.8308091 0.8308091
#> 192     0.9024807 0.9024807
#> 193     0.8710555 0.8710555
#> 194     0.9401604 0.9401604
#> 195     0.8943335 0.8943335
#> 196     0.8840054 0.8840054
#> 197     0.9396170 0.9396170
#> 198     0.9032681 0.9032681
#> 199     0.9042502 0.9042502
#> 200     0.9124618 0.9124618
#> 201     0.8809348 0.8809348
#> 202     0.9018260 0.9018260
#> 203     0.9151076 0.9151076
#> 204     0.9350306 0.9350306
#> 205     0.8945606 0.8945606
#> 206     0.9136941 0.9136941
#> 207     0.9242520 0.9242520
#> 208     0.9326962 0.9326962
#> 209     0.9124778 0.9124778
#> 210     0.8975712 0.8975712
#> 211     0.9121218 0.9121218
#> 212     0.8950624 0.8950624
#> 213     0.9153424 0.9153424
#> 214     0.9400220 0.9400220
#> 215     0.9282866 0.9282866
#> 216     0.9086460 0.9086460
#> 217     0.9288044 0.9288044
#> 218     0.9400786 0.9400786
#> 219     0.8673718 0.8673718
#> 220     0.9158879 0.9158879
#> 221     0.8535410 0.8535410
#> 222     0.9400217 0.9400217
#> 223     0.8851959 0.8851959
#> 224     0.9060383 0.9060383
#> 225     0.9062101 0.9062101
#> 226     0.8848013 0.8848013
#> 227     0.8789860 0.8789860
#> 228     0.8900925 0.8900925
#> 229     0.9234899 0.9234899
#> 230     0.8701972 0.8701972
#> 231     0.9279874 0.9279874
#> 232     0.8092670 0.8092670
#> 233     0.9400496 0.9400496
#> 234     0.9290636 0.9290636
#> 235     0.9208276 0.9208276
#> 236     0.8721429 0.8721429
#> 237     0.8321699 0.8321699
#> 238     0.9400358 0.9400358
#> 239     0.9275849 0.9275849
#> 240     0.8827362 0.8827362
#> 241     0.9374547 0.9374547
#> 242     0.8902573 0.8902573
#> 243     0.8433879 0.8433879
#> 244     0.9400350 0.9400350
#> 245     0.9400261 0.9400261
#> 246     0.9054156 0.9054156
#> 247     0.9090685 0.9090685
#> 248     0.8151271 0.8151271
#> 249     0.9113556 0.9113556
#> 250     0.9163270 0.9163270
#> 251     0.8686294 0.8686294
#> 252     0.9101426 0.9101426
#> 253     0.8590973 0.8590973
#> 254     0.8968207 0.8968207
#> 255     0.8968553 0.8968553
#> 256     0.8708957 0.8708957
#> 257     0.8738887 0.8738887
#> 258     0.9248610 0.9248610
#> 259     0.8997574 0.8997574
#> 260     0.8423321 0.8423321
#> 261     0.8753098 0.8753098
#> 262     0.8474781 0.8474781
#> 263     0.8932308 0.8932308
#> 264     0.8067456 0.8067456
#> 265     0.9367089 0.9367089
#> 266     0.9276743 0.9276743
#> 267     0.8978018 0.8978018
#> 268     0.8927138 0.8927138
#> 269     0.8966086 0.8966086
#> 270     0.8707553 0.8707553
#> 271     0.8843355 0.8843355
#> 272     0.8971030 0.8971030
#> 273     0.9180542 0.9180542
#> 274     0.9400044 0.9400044
#> 275     0.8833942 0.8833942
#> 276     0.9011282 0.9011282
#> 277     0.9057563 0.9057563
#> 278     0.9400667 0.9400667
#> 279     0.8770794 0.8770794
#> 280     0.8958722 0.8958722
#> 281     0.9229663 0.9229663
#> 282     0.8915310 0.8915310
#> 283     0.8999256 0.8999256
#> 284     0.8954752 0.8954752
#> 285     0.8869861 0.8869861
#> 286     0.9400736 0.9400736
#> 287     0.9168706 0.9168706
#> 288     0.8576416 0.8576416
#> 289     0.9401518 0.9401518
#> 290     0.8484114 0.8484114
#> 291     0.7800476 0.7800476
#> 292     0.9230769 0.9230769
#> 293     0.9197013 0.9197013
#> 294     0.8524229 0.8524229
#> 295     0.9168221 0.9168221
#> 296     0.8324236 0.8324236
#> 297     0.8948330 0.8948330
#> 298     0.9308743 0.9308743
#> 299     0.9212942 0.9212942
#> 300     0.8847831 0.8847831
#> 301     0.9400011 0.9400011
#> 302     0.9400072 0.9400072
#> 303     0.9322430 0.9322430
#> 304     0.9378459 0.9378459
#> 305     0.9007548 0.9007548
#> 306     0.9071486 0.9071486
#> 307     0.9401431 0.9401431
#> 308     0.8659874 0.8659874
#> 309     0.9257267 0.9257267
#> 310     0.9399807 0.9399807
#> 311     0.9400507 0.9400507
#> 312     0.8830154 0.8830154
#> 313     0.7881531 0.7881531
#> 314     0.9313491 0.9313491
#> 315     0.8977690 0.8977690
#> 316     0.8906270 0.8906270
#> 317     0.9378828 0.9378828
#> 318     0.9101510 0.9101510
#> 319     0.9041879 0.9041879
#> 320     0.9105393 0.9105393
#> 321     0.8931069 0.8931069
#> 322     0.8926709 0.8926709
#> 323     0.8662414 0.8662414
#> 324     0.8979167 0.8979167
#> 325     0.9266201 0.9266201
#> 326     0.9007068 0.9007068
#> 327     0.9400000 0.9400000
#> 328     0.8606424 0.8606424